## no critic: TestingAndDebugging::RequireStrict
package Sah::SchemaR::perl::arraydata::modnames_with_optional_args;

our $DATE = '2022-09-25'; # DATE
our $VERSION = '0.004'; # VERSION

our $rschema = do{my$var={base=>"array",clsets_after_base=>[{description=>"\nArray of Perl ArrayData::* module names without the prefix and optional args.\nEach element is of `perl::arraydata::modname` schema, e.g.\n`Lingua::Word::ID::KBBI`, `WordList=wordlist,EN::Enable`.\n\nContains coercion rule that expands wildcard, so you can specify:\n\n    Lingua::Word::ID::*\n\nand it will be expanded to e.g.:\n\n    [\"Lingua::Word::ID::KBBI\", \"Word::ID::PERLANCAR\"]\n\nThe wildcard syntax supports jokers (`?`, `*`, `**`), brackets (`[abc]`), and\nbraces (`{one,two}`). See <pm:Module::List::Wildcard> for more details.\n\n",of=>["perl::arraydata::modname_with_optional_args",{req=>1},{}],summary=>"Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. [\"Lingua::Word::ID::KBBI\", \"WordList=wordlist,EN::Enable\"]","x.element_completion"=>["perl_modname",{ns_prefix=>"ArrayData"}],"x.perl.coerce_rules"=>[["From_str_or_array::expand_perl_modname_wildcard",{ns_prefix=>"ArrayData"}]]}],clsets_after_type=>['$var->{clsets_after_base}[0]'],"clsets_after_type.alt.merge.merged"=>['$var->{clsets_after_base}[0]'],resolve_path=>["array"],type=>"array",v=>2};$var->{clsets_after_type}[0]=$var->{clsets_after_base}[0];$var->{"clsets_after_type.alt.merge.merged"}[0]=$var->{clsets_after_base}[0];$var};

1;
# ABSTRACT: Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Lingua::Word::ID::KBBI", "WordList=wordlist,EN::Enable"]

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::perl::arraydata::modnames_with_optional_args - Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Lingua::Word::ID::KBBI", "WordList=wordlist,EN::Enable"]

=head1 VERSION

This document describes version 0.004 of Sah::SchemaR::perl::arraydata::modnames_with_optional_args (from Perl distribution Sah-Schemas-ArrayData), released on 2022-09-25.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-ArrayData>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-ArrayData>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-ArrayData>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
